When the server application receives unexpected input, an error is triggered returning technical information about the application internals.

An attacker can use this information to understand how the application is handling inputs. It becomes possible to investigate the inner workings and formulate further attack strategies. Information leakage should be suppressed to discourage attackers and prevent access to potential critical information.